@@ -6,6 +6,7 @@ BCS SDK: http://developer.baidu.com/wiki/index.php?title=docs/cplat/bcs/sdk
 import os
 from .base import BaseBackend
 from pybcs import BCS
+from ..utils import filter_delete_filename_list
 
 BCS_HOST = 'bcs.duapp.com'
 
@@ -37,3 +38,13 @@ class BCSBackend(BaseBackend):
 
         obj = self.bucket.object(os.path.join('/', category, filename))
         obj.put_file(file_path)
+
+    def clean(self, category, keeps):
+        # 和阿里云不一样，必须以 / 开头
+        obj_list = self.bucket.list_objects('/' + category + '/')
+        filename_list = [obj.object_name for obj in obj_list]
+
+        delete_filename_list = set(filter_delete_filename_list(filename_list, keeps))
+        for obj in obj_list:
+            if obj.object_name in delete_filename_list:
+                obj.delete()
