@@ -9,14 +9,17 @@ import shutil
 
 import sh
 
+import constants
+
 logger = logging.getLogger(__name__)
 
 
 class YunBK(object):
 
-    def __init__(self, backup_name, backends):
+    def __init__(self, backup_name, backends, keeps=None):
         self.backup_name = backup_name
         self.backends = backends
+        self.keeps = keeps
         self.dir_prefix = "{0}_".format(backup_name)
 
     def __enter__(self):
@@ -44,7 +47,7 @@ class YunBK(object):
         """
 
         now = datetime.datetime.now()
-        str_now = now.strftime('%Y%m%d_%H%M%S')
+        str_now = now.strftime(constants.STRFTIME_TPL)
 
         tar_filepath = os.path.join(tempfile.gettempdir(), '%s.%s.tar' % (self.backup_name, str_now))
 
@@ -60,3 +63,17 @@ class YunBK(object):
             raise e
         finally:
             os.remove(tar_filepath)
+
+        # 清理
+        self.rotate()
+
+    def rotate(self):
+        """
+        清理无用的
+        """
+        if not self.keeps:
+            # 就是不删除
+            return
+
+        for backend in self.backends:
+            backend.clean(self.backup_name, self.keeps)
